import{C as p,_ as n}from"./View.vue_vue_type_script_setup_true_lang-BShaGmrx.js";import{a as i,ac as s,p as a,e as m,u as c}from"./jwt-decode.esm-DPxUepXu.js";import"./router-DJih1Hg3.js";import"./ts.worker-DNiEYtn5.js";import"./fetch-C3Xn4ugN.js";import"./record-CEMNknUx.js";import"./SaveButton-B0jbaOQy.js";import"./ExclamationCircleOutlined-ECpe7S2u.js";import"./CrudView-DOTRvvbq.js";import"./DocsButton.vue_vue_type_script_setup_true_lang-DBSvqDE4.js";import"./constants-X52IQ9Ps.js";import"./url-D-YQ5puQ.js";import"./PhDotsThreeVertical.vue-Cevc2QFg.js";import"./index-Dhs6cLFJ.js";import"./asyncComputed-DaiiKC7j.js";import"./omniChatStore-Byaj4pOr.js";import"./uuid-Dgxt1inB.js";import"./PhCopySimple.vue-CfWqQkIJ.js";import"./PhPencil.vue-CbU34hFk.js";import"./useCodebaseEvents-iIm8K8EU.js";import"./contracts.generated-BsKs6GQB.js";import"./index-CAcZ5QF-.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="230ca48c-a644-4640-8542-45412115e5ee",o._sentryDebugIdIdentifier="sentry-dbid-230ca48c-a644-4640-8542-45412115e5ee")}catch{}})();const A=i({__name:"EnvVars",setup(o){const r=s().params.projectId,t=new p(r);return(d,u)=>(m(),a(n,{"env-var-repository":c(t),mode:"console"},null,8,["env-var-repository"]))}});export{A as default};
//# sourceMappingURL=EnvVars-KvRriX9B.js.map
