const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=["assets/OidcLoginCallback-d3Rmw-pW.js","assets/workspaceStore-BpEDIRCC.js","assets/jwt-decode.esm-DPxUepXu.js","assets/jwt-decode-D9e-DIPp.css","assets/userStore-Bt7tYPGp.js","assets/url-D-YQ5puQ.js","assets/colorHelpers-mTQK8wKi.js","assets/OidcLogoutCallback-DOzzaZhw.js","assets/Login-DIFS1IPF.js","assets/Login.vue_vue_type_script_setup_true_lang-DvDpKcfK.js","assets/OTPInput-CjXP6YQT.js","assets/OTPInput-C8ldH5jb.css","assets/Logo-CAibQBUf.js","assets/Logo-D2kepPyK.css","assets/string-B5AbZUMC.js","assets/CircularLoading-17mT-AAg.js","assets/CircularLoading-BiyobKo3.css","assets/index-CAcZ5QF-.js","assets/Login-cMuNqCbG.css","assets/Login-C1k-SC0u.css","assets/Main-DXH5yJXd.js","assets/PlayerNavbar-CEC56dkR.js","assets/metadata-DOEACOwt.js","assets/PhMagnifyingGlass.vue-DrKM6BHB.js","assets/PhWebhooksLogo.vue-gVRou3p6.js","assets/LoadingOutlined-CuvrcbFk.js","assets/PhSignOut.vue-U2TYVuaS.js","assets/index-D9-dKMGQ.js","assets/PlayerNavbar-VlEtzX8f.css","assets/Main-DqPmGmnC.css","assets/Home-BD-6BtyG.js","assets/Watermark-BJuHR4ao.js","assets/constants-X52IQ9Ps.js","assets/Watermark-DMbnzHiR.css","assets/PhArrowSquareOut.vue-B6QbTF59.js","assets/index-Kyy4iqsa.js","assets/Home-B6UGln4L.css","assets/Error-CHKDB1g8.js","assets/AbstraLogo.vue_vue_type_script_setup_true_lang-CmYu39hp.js","assets/Error-CIbhyrKS.css","assets/Form-Cn9E9wog.js","assets/FormRunner-CkM-RtPx.js","assets/Steps-2LBOSv0W.js","assets/index-BkzXuLDR.js","assets/Steps-DqO_G9S3.css","assets/FormRunner-Fkp92u0R.css","assets/redirect-DXZWtyQS.js","assets/asyncComputed-DaiiKC7j.js","assets/uuid-Dgxt1inB.js","assets/Form-CshGBPDC.css"])))=>i.map(i=>d[i]);
import{ag as d,ah as s,ad as t,ai as m}from"./jwt-decode.esm-DPxUepXu.js";import{a as u}from"./workspaceStore-BpEDIRCC.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="3f9213e2-6c84-47db-a353-c96e79e4bb10",e._sentryDebugIdIdentifier="sentry-dbid-3f9213e2-6c84-47db-a353-c96e79e4bb10")}catch{}})();const f=async()=>{try{const e=await fetch("/_editor/api/workspace/version");return e.ok&&(await e.json()).version||"cdd9f50d9370389b4ed4d39a9d190ccf5667ce79"}catch(e){return console.error("Failed to fetch Abstra version:",e),"cdd9f50d9370389b4ed4d39a9d190ccf5667ce79"}},p=[{path:"/oidc-login-callback",name:"oidcLoginCallback",component:()=>t(()=>import("./OidcLoginCallback-d3Rmw-pW.js"),__vite__mapDeps([0,1,2,3,4,5,6])),meta:{allowUnauthenticated:!0}},{path:"/oidc-logout-callback",name:"oidcLogoutCallback",component:()=>t(()=>import("./OidcLogoutCallback-DOzzaZhw.js"),__vite__mapDeps([7,1,2,3,4,5,6])),meta:{allowUnauthenticated:!0}},{path:"/login",name:"playerLogin",component:()=>t(()=>import("./Login-DIFS1IPF.js"),__vite__mapDeps([8,9,2,3,1,4,5,6,10,11,12,13,14,15,16,17,18,19])),meta:{allowUnauthenticated:!0}},{path:"/",name:"main",component:()=>t(()=>import("./Main-DXH5yJXd.js"),__vite__mapDeps([20,21,4,2,3,1,5,6,22,23,24,25,26,27,28,29])),redirect:{name:"main"},children:[{path:"",name:"playerHome",component:()=>t(()=>import("./Home-BD-6BtyG.js"),__vite__mapDeps([30,22,2,3,23,24,31,1,4,5,6,32,33,34,35,25,36])),meta:{title:"Home"}},{path:"_player/threads",redirect:{name:"playerThreads"}},{path:"error/:status",name:"error",component:()=>t(()=>import("./Error-CHKDB1g8.js"),__vite__mapDeps([37,38,12,2,3,13,32,1,4,5,6,35,39])),meta:{allowUnauthenticated:!0}},{path:":path(.*)*",name:"form",component:()=>t(()=>import("./Form-Cn9E9wog.js"),__vite__mapDeps([40,4,2,3,41,9,1,5,6,10,11,12,13,14,15,16,17,18,42,43,44,31,32,33,45,46,47,48,49])),meta:{hideLogin:!0}}]}],o=d({history:s("/"),routes:p,scrollBehavior(e){if(e.hash)return{el:e.hash}}}),l=e=>async(a,r)=>{if(m(a,r),a.meta.allowUnauthenticated)return;const n=await u(a.path),{redirect:c,...i}=a.query;switch(n.status){case"ALLOWED":break;case"UNAUTHORIZED":await e.push({name:"playerLogin",query:{...i,redirect:c||a.path},params:a.params});break;case"NOT_FOUND":await e.push({name:"error",params:{status:"404"}});break;default:await e.push({name:"error",params:{status:"403"}})}};o.beforeEach(l(o));export{p as a,l as b,f as g,o as r};
//# sourceMappingURL=router-6LQn4Oq4.js.map
